@@ -1,11 +1,11 @@
-#!/usr/bin/env ruby
+#!/usr/bin/ruby
 
 =begin
 
   rbbr.rb - Ruby Meta-Level Information Browser
 
-  $Author: klamath $
-  $Date: 2001/10/04 02:13:22 $
+  $Author: mutoh $
+  $Date: 2002/06/04 15:49:49 $
 
   Copyright (C) 2000-2001 Hiroshi Igarashi
 
@@ -20,8 +20,8 @@
 
   meta/metainfo.rb - API for Meta-level Information
 
-  $Author: klamath $
-  $Date: 2001/10/04 02:13:22 $
+  $Author: mutoh $
+  $Date: 2002/06/04 15:49:49 $
 
   Copyright (C) 2000 Hiroshi Igarashi
 
@@ -308,8 +308,8 @@ require 'gtk'
 
   gtkutil.rb - Gtk Utility
 
-  $Author: klamath $
-  $Date: 2001/10/04 02:13:22 $
+  $Author: mutoh $
+  $Date: 2002/06/04 15:49:49 $
 
   Copyright (C) 2000 Hiroshi Igarashi
 
@@ -430,8 +430,8 @@ end
 
   meta/browser.rb - Meta-Level Information Browser
 
-  $Author: klamath $
-  $Date: 2001/10/04 02:13:22 $
+  $Author: mutoh $
+  $Date: 2002/06/04 15:49:49 $
 
   Copyright (C) 2000-2001 Hiroshi Igarashi
 
